@@ -14,32 +14,50 @@ See the License for the specific language governing permissions and
 limitations under the License.
 
 """
-import falcon
-from paste import deploy
-from pkg_resources import parse_version
 import sys
 
-from freezer_api.cmd.api import build_app_v0
-from freezer_api.cmd.api import build_app_v1
+import falcon
+from oslo_config import cfg
+from paste import deploy
+from paste import urlmap
+import pkg_resources
+
+from freezer_api.cmd import api
 from freezer_api.common import config
 
-
+CONF = cfg.CONF
 # Define the minimum version of falcon at which we can use the "new" invocation
 # style for middleware (aka v1), i.e. the "middleware" named argument for
 # falcon.API.
-FALCON_MINVERSION_MIDDLEWARE = parse_version('0.2.0b1')
+FALCON_MINVERSION_MIDDLEWARE = pkg_resources.parse_version('0.2.0b1')
 
 
-def freezer_app_factory(global_conf, **local_conf):
-    current_version = parse_version(
-        falcon.__version__ if hasattr(falcon, '__version__') else falcon.version)
+def root_app_factory(loader, global_conf, **local_conf):
+    """Allows freezer to launch multiple applications at a time.
+    It will allow freezer to manage multiple versions.
+    """
+    if not CONF.enable_v1_api and '/v1' in local_conf:
+        del local_conf['/v1']
+    if not CONF.enable_v2_api and '/v2' in local_conf:
+        del local_conf['/v2']
+    return urlmap.urlmap_factory(loader, global_conf, **local_conf)
+
+
+def freezer_appv1_factory(global_conf, **local_conf):
+    current_version = pkg_resources.parse_version(
+        falcon.__version__ if hasattr(falcon,
+                                      '__version__') else falcon.version)
 
     # Check the currently installed version of falcon in order to invoke it
     # correctly.
     if current_version < FALCON_MINVERSION_MIDDLEWARE:
-        return build_app_v0()
+        return api.build_app_v0()
     else:
-        return build_app_v1()
+        return api.build_app_v1()
+
+
+def freezer_appv2_factory(global_conf, **local_conf):
+    return api.build_app_v2()
 
 
 def initialize_app(conf=None, name='main'):
@@ -53,4 +71,3 @@ def initialize_app(conf=None, name='main'):
     conf = config.find_paste_config()
     app = deploy.loadapp('config:%s' % conf, name=name)
     return app
-
