@@ -15,12 +15,13 @@
 import json
 import time
 
+from tempest.lib import decorators
+from tempest.lib import exceptions
+
 from freezer_api.tests.freezer_api_tempest_plugin.tests.api import base
-from tempest import test
-from tempest.lib.exceptions import BadRequest
+
 
 class TestFreezerApiClients(base.BaseFreezerApiTest):
-
     @classmethod
     def resource_setup(cls):
         super(TestFreezerApiClients, cls).resource_setup()
@@ -29,7 +30,7 @@ class TestFreezerApiClients(base.BaseFreezerApiTest):
     def resource_cleanup(cls):
         super(TestFreezerApiClients, cls).resource_cleanup()
 
-    @test.attr(type="gate")
+    @decorators.attr(type="gate")
     def test_api_clients(self):
 
         resp, response_body = self.freezer_api_client.get_clients()
@@ -38,9 +39,9 @@ class TestFreezerApiClients(base.BaseFreezerApiTest):
         response_body_json = json.loads(response_body)
         self.assertIn('clients', response_body_json)
         clients = response_body_json['clients']
-        self.assertEqual([], clients)
+        self.assertEmpty(clients)
 
-    @test.attr(type="gate")
+    @decorators.attr(type="gate")
     def test_api_clients_get_limit(self):
         # limits > 0 should return successfully
         for valid_limit in [2, 1]:
@@ -49,11 +50,11 @@ class TestFreezerApiClients(base.BaseFreezerApiTest):
 
         # limits <= 0 should raise a bad request error
         for bad_limit in [0, -1, -2]:
-            self.assertRaises(BadRequest,
+            self.assertRaises(exceptions.BadRequest,
                               self.freezer_api_client.get_clients,
                               limit=bad_limit)
 
-    @test.attr(type="gate")
+    @decorators.attr(type="gate")
     def test_api_clients_get_offset(self):
         # offsets >= 0 should return 200
         for valid_offset in [1, 0]:
@@ -63,14 +64,12 @@ class TestFreezerApiClients(base.BaseFreezerApiTest):
 
         # offsets < 0 should return 400
         for bad_offset in [-1, -2]:
-            self.assertRaises(BadRequest,
+            self.assertRaises(exceptions.BadRequest,
                               self.freezer_api_client.get_clients,
                               offset=bad_offset)
 
-    @test.attr(type="gate")
+    @decorators.attr(type="gate")
     def test_api_clients_post(self):
-
-
         client = {'client_id': 'test-client-id',
                   'hostname': 'test-host-name',
                   'description': 'a test client',
