@@ -16,46 +16,46 @@ limitations under the License.
 
 """
 
-import unittest
-from mock import Mock, MagicMock, patch
-
-import random
 import json
+import random
 
-from .common import *
-from freezer_api.common.exceptions import *
+import falcon
+import mock
+from mock import patch
 
 from freezer_api.api.v1 import jobs as v1_jobs
+from freezer_api.common import exceptions
+from freezer_api.tests.unit import common
 
 
-class TestJobsBaseResource(FreezerBaseTestCase):
-
+class TestJobsBaseResource(common.FreezerBaseTestCase):
     def setUp(self):
         super(TestJobsBaseResource, self).setUp()
-        self.mock_db = Mock()
+        self.mock_db = mock.Mock()
         self.resource = v1_jobs.JobsBaseResource(self.mock_db)
 
     def test_get_action_returns_found_action(self):
         self.mock_db.get_action.return_value = 'awesome_result'
         result = self.resource.get_action('user-id', 'action-id')
-        self.assertEquals(result, 'awesome_result')
+        self.assertEqual(result, 'awesome_result')
 
     def test_get_action_returns_none_when_action_not_found(self):
-        self.mock_db.get_action.side_effect = DocumentNotFound('regular test failure')
+        self.mock_db.get_action.side_effect = exceptions.DocumentNotFound(
+            'regular test failure')
         result = self.resource.get_action('user-id', 'action-id')
         self.assertIsNone(result)
 
     def test_update_actions_in_job_no_action_id(self):
-        self.resource.get_action = Mock()
+        self.resource.get_action = mock.Mock()
         self.resource.get_action.return_value = None
         action_doc = {
-                #"action_id": "ottonero",
-                "freezer_action": {
-                                "mode" : "mysql",
-                                "container": "freezer_backup_test"
-                },
-                "max_retries": 3
-            }
+            # "action_id": "ottonero",
+            "freezer_action": {
+                "mode": "mysql",
+                "container": "freezer_backup_test"
+            },
+            "max_retries": 3
+        }
         job_doc = {"job_actions": [action_doc.copy()],
                    "description": "three actions backup"
                    }
@@ -64,16 +64,16 @@ class TestJobsBaseResource(FreezerBaseTestCase):
                                                    doc=action_doc)
 
     def test_update_actions_in_job_action_id_not_found(self):
-        self.resource.get_action = Mock()
+        self.resource.get_action = mock.Mock()
         self.resource.get_action.return_value = None
         action_doc = {
-                "action_id": "ottonero",
-                "freezer_action": {
-                                "mode" : "mysql",
-                                "container": "freezer_backup_test"
-                },
-                "max_retries": 3
-            }
+            "action_id": "ottonero",
+            "freezer_action": {
+                "mode": "mysql",
+                "container": "freezer_backup_test"
+            },
+            "max_retries": 3
+        }
         job_doc = {"job_actions": [action_doc.copy()],
                    "description": "three actions backup"
                    }
@@ -82,15 +82,15 @@ class TestJobsBaseResource(FreezerBaseTestCase):
                                                    doc=action_doc)
 
     def test_update_actions_in_job_action_id_found_and_same_action(self):
-        self.resource.get_action = Mock()
+        self.resource.get_action = mock.Mock()
         action_doc = {
-                "action_id": "ottonero",
-                "freezer_action": {
-                                "mode" : "mysql",
-                                "container": "freezer_backup_test"
-                },
-                "max_retries": 3
-            }
+            "action_id": "ottonero",
+            "freezer_action": {
+                "mode": "mysql",
+                "container": "freezer_backup_test"
+            },
+            "max_retries": 3
+        }
         job_doc = {"job_actions": [action_doc.copy()],
                    "description": "three actions backup"
                    }
@@ -99,27 +99,27 @@ class TestJobsBaseResource(FreezerBaseTestCase):
         self.mock_db.add_action.assert_not_called()
 
     def test_update_actions_in_job_action_id_found_and_different_action(self):
-        self.resource.get_action = Mock()
+        self.resource.get_action = mock.Mock()
         action_doc = {
-                "action_id": "ottonero",
-                "freezer_action": {
-                                "mode" : "mysql",
-                                "container": "freezer_backup_test"
-                },
-                "max_retries": 3
-            }
+            "action_id": "ottonero",
+            "freezer_action": {
+                "mode": "mysql",
+                "container": "freezer_backup_test"
+            },
+            "max_retries": 3
+        }
         job_doc = {"job_actions": [action_doc.copy()],
                    "description": "three actions backup"
                    }
 
         found_action = {
-                "action_id": "ottonero",
-                "freezer_action": {
-                                "mode" : "mysql",
-                                "container": "different_drum"
-                },
-                "max_retries": 4
-            }
+            "action_id": "ottonero",
+            "freezer_action": {
+                "mode": "mysql",
+                "container": "different_drum"
+            },
+            "max_retries": 4
+        }
 
         new_doc = action_doc.copy()
         new_doc['action_id'] = ''
@@ -129,16 +129,15 @@ class TestJobsBaseResource(FreezerBaseTestCase):
                                                    doc=new_doc)
 
 
-class TestJobsCollectionResource(FreezerBaseTestCase):
-
+class TestJobsCollectionResource(common.FreezerBaseTestCase):
     def setUp(self):
         super(TestJobsCollectionResource, self).setUp()
-        self.mock_json_body = Mock()
+        self.mock_json_body = mock.Mock()
         self.mock_json_body.return_value = {}
-        self.mock_db = Mock()
-        self.mock_req = MagicMock()
-        self.mock_req.__getitem__.side_effect = get_req_items
-        self.mock_req.get_header.return_value = fake_job_0_user_id
+        self.mock_db = mock.Mock()
+        self.mock_req = mock.MagicMock()
+        self.mock_req.__getitem__.side_effect = common.get_req_items
+        self.mock_req.get_header.return_value = common.fake_job_0_user_id
         self.mock_req.status = falcon.HTTP_200
         self.resource = v1_jobs.JobsCollectionResource(self.mock_db)
         self.resource.json_body = self.mock_json_body
@@ -152,15 +151,17 @@ class TestJobsCollectionResource(FreezerBaseTestCase):
         self.assertEqual(self.mock_req.status, falcon.HTTP_200)
 
     def test_on_get_return_correct_list(self):
-        self.mock_db.search_job.return_value = [get_fake_job_0(), get_fake_job_1()]
-        expected_result = {'jobs': [get_fake_job_0(), get_fake_job_1()]}
+        self.mock_db.search_job.return_value = [common.get_fake_job_0(),
+                                                common.get_fake_job_1()]
+        expected_result = {
+            'jobs': [common.get_fake_job_0(), common.get_fake_job_1()]}
         self.resource.on_get(self.mock_req, self.mock_req)
         result = self.mock_req.body
         self.assertEqual(result, expected_result)
         self.assertEqual(self.mock_req.status, falcon.HTTP_200)
 
     def test_on_post_inserts_correct_data(self):
-        job = get_fake_job_0()
+        job = common.get_fake_job_0()
         self.mock_json_body.return_value = job
         self.mock_db.add_job.return_value = 'pjiofrdslaikfunr'
         expected_result = {'job_id': 'pjiofrdslaikfunr'}
@@ -169,15 +170,14 @@ class TestJobsCollectionResource(FreezerBaseTestCase):
         self.assertEqual(self.mock_req.body, expected_result)
 
 
-class TestJobsResource(FreezerBaseTestCase):
-
+class TestJobsResource(common.FreezerBaseTestCase):
     def setUp(self):
         super(TestJobsResource, self).setUp()
-        self.mock_db = Mock()
-        self.mock_req = MagicMock()
-        self.mock_req.__getitem__.side_effect = get_req_items
+        self.mock_db = mock.Mock()
+        self.mock_req = mock.MagicMock()
+        self.mock_req.__getitem__.side_effect = common.get_req_items
         self.mock_req.stream.read.return_value = {}
-        self.mock_req.get_header.return_value = fake_job_0_user_id
+        self.mock_req.get_header.return_value = common.fake_job_0_user_id
         self.mock_req.status = falcon.HTTP_200
         self.resource = v1_jobs.JobsResource(self.mock_db)
 
@@ -187,22 +187,25 @@ class TestJobsResource(FreezerBaseTestCase):
     def test_on_get_return_no_result_and_404_when_not_found(self):
         self.mock_req.body = None
         self.mock_db.get_job.return_value = None
-        self.resource.on_get(self.mock_req, self.mock_req, fake_job_0_job_id)
+        self.resource.on_get(self.mock_req, self.mock_req,
+                             common.fake_job_0_job_id)
         self.assertIsNone(self.mock_req.body)
         self.assertEqual(self.mock_req.status, falcon.HTTP_404)
 
     def test_on_get_return_correct_data(self):
-        self.mock_db.get_job.return_value = get_fake_job_0()
-        self.resource.on_get(self.mock_req, self.mock_req, fake_job_0_job_id)
+        self.mock_db.get_job.return_value = common.get_fake_job_0()
+        self.resource.on_get(self.mock_req, self.mock_req,
+                             common.fake_job_0_job_id)
         result = self.mock_req.body
-        self.assertEqual(result, get_fake_job_0())
+        self.assertEqual(result, common.get_fake_job_0())
         self.assertEqual(self.mock_req.status, falcon.HTTP_200)
 
     def test_on_delete_removes_proper_data(self):
-        self.resource.on_delete(self.mock_req, self.mock_req, fake_job_0_job_id)
+        self.resource.on_delete(self.mock_req, self.mock_req,
+                                common.fake_job_0_job_id)
         result = self.mock_req.body
-        expected_result = {'job_id': fake_job_0_job_id}
-        self.assertEquals(self.mock_req.status, falcon.HTTP_204)
+        expected_result = {'job_id': common.fake_job_0_job_id}
+        self.assertEqual(self.mock_req.status, falcon.HTTP_204)
         self.assertEqual(result, expected_result)
 
     def test_on_patch_ok_with_some_fields(self):
@@ -212,13 +215,14 @@ class TestJobsResource(FreezerBaseTestCase):
                      'because': 'size_matters',
                      'job_schedule': {}}
         self.mock_req.stream.read.return_value = json.dumps(patch_doc)
-        expected_result = {'job_id': fake_job_0_job_id,
+        expected_result = {'job_id': common.fake_job_0_job_id,
                            'version': new_version}
-        self.resource.update_actions_in_job = Mock()
-        self.resource.on_patch(self.mock_req, self.mock_req, fake_job_0_job_id)
+        self.resource.update_actions_in_job = mock.Mock()
+        self.resource.on_patch(self.mock_req, self.mock_req,
+                               common.fake_job_0_job_id)
         self.mock_db.update_job.assert_called_with(
-            user_id=fake_job_0_user_id,
-            job_id=fake_job_0_job_id,
+            user_id=common.fake_job_0_user_id,
+            job_id=common.fake_job_0_job_id,
             patch_doc=patch_doc)
         self.assertEqual(self.mock_req.status, falcon.HTTP_200)
         result = self.mock_req.body
@@ -227,36 +231,38 @@ class TestJobsResource(FreezerBaseTestCase):
     def test_on_post_ok(self):
         new_version = random.randint(0, 99)
         self.mock_db.replace_job.return_value = new_version
-        job = get_fake_job_0()
+        job = common.get_fake_job_0()
         self.mock_req.stream.read.return_value = json.dumps(job)
-        expected_result = {'job_id': fake_job_0_job_id,
+        expected_result = {'job_id': common.fake_job_0_job_id,
                            'version': new_version}
 
-        self.resource.on_post(self.mock_req, self.mock_req, fake_job_0_job_id)
+        self.resource.on_post(self.mock_req, self.mock_req,
+                              common.fake_job_0_job_id)
         self.assertEqual(self.mock_req.status, falcon.HTTP_201)
         self.assertEqual(self.mock_req.body, expected_result)
 
     def test_on_post_raises_when_db_replace_job_raises(self):
-        self.mock_db.replace_job.side_effect = AccessForbidden('regular test failure')
-        job = get_fake_job_0()
+        self.mock_db.replace_job.side_effect = exceptions.AccessForbidden(
+            'regular test failure')
+        job = common.get_fake_job_0()
         self.mock_req.stream.read.return_value = json.dumps(job)
-        self.assertRaises(AccessForbidden, self.resource.on_post,
+        self.assertRaises(exceptions.AccessForbidden, self.resource.on_post,
                           self.mock_req,
                           self.mock_req,
-                          fake_job_0_job_id)
+                          common.fake_job_0_job_id)
 
 
-class TestJobsEvent(FreezerBaseTestCase):
-
+class TestJobsEvent(common.FreezerBaseTestCase):
     def setUp(self):
         super(TestJobsEvent, self).setUp()
-        self.mock_db = Mock()
-        self.mock_req = MagicMock()
-        self.mock_req.__getitem__.side_effect = get_req_items
-        self.mock_req.get_header.return_value = fake_session_0['user_id']
+        self.mock_db = mock.Mock()
+        self.mock_req = mock.MagicMock()
+        self.mock_req.__getitem__.side_effect = common.get_req_items
+        self.mock_req.get_header.return_value = common.fake_session_0[
+            'user_id']
         self.mock_req.status = falcon.HTTP_200
         self.resource = v1_jobs.JobsEvent(self.mock_db)
-        self.mock_json_body = Mock()
+        self.mock_json_body = mock.Mock()
         self.mock_json_body.return_value = {}
         self.resource.json_body = self.mock_json_body
 
@@ -265,7 +271,7 @@ class TestJobsEvent(FreezerBaseTestCase):
 
     def test_on_post_raises_when_unable_to_read_event_from_body(self):
         self.mock_json_body.return_value = {}
-        self.assertRaises(BadDataFormat, self.resource.on_post,
+        self.assertRaises(exceptions.BadDataFormat, self.resource.on_post,
                           self.mock_req,
                           self.mock_req,
                           'my_job_id')
@@ -286,8 +292,7 @@ class TestJobsEvent(FreezerBaseTestCase):
         self.assertEqual(self.mock_req.body, expected_result)
 
 
-class TestJobs(FreezerBaseTestCase):
-
+class TestJobs(common.FreezerBaseTestCase):
     def setUp(self):
         super(TestJobs, self).setUp()
 
@@ -299,7 +304,7 @@ class TestJobs(FreezerBaseTestCase):
             job_schedule['event'] = event
         job = v1_jobs.Job({'job_schedule': job_schedule})
         res = job.start()
-        self.assertEquals(res, response)
+        self.assertEqual(res, response)
         self.assertEqual(job.need_update, need_update)
 
     def _test_job_stop(self, status, event, response, need_update):
@@ -310,7 +315,7 @@ class TestJobs(FreezerBaseTestCase):
             job_schedule['event'] = event
         job = v1_jobs.Job({'job_schedule': job_schedule})
         res = job.stop()
-        self.assertEquals(res, response)
+        self.assertEqual(res, response)
         self.assertEqual(job.need_update, need_update)
 
     def _test_job_abort(self, status, event, response, need_update):
@@ -321,15 +326,14 @@ class TestJobs(FreezerBaseTestCase):
             job_schedule['event'] = event
         job = v1_jobs.Job({'job_schedule': job_schedule})
         res = job.abort()
-        self.assertEquals(res, response)
+        self.assertEqual(res, response)
         self.assertEqual(job.need_update, need_update)
 
-
     def test_start_scheduled_unstarted_job(self):
         self._test_job_start(status='scheduled',
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     def test_start_scheduled_started_job(self):
         self._test_job_start(status='scheduled',
@@ -459,91 +463,92 @@ class TestJobs(FreezerBaseTestCase):
 
     def test_abort_scheduled_unaborted_job(self):
         self._test_job_abort(status='scheduled',
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     def test_abort_scheduled_abortped_job(self):
         self._test_job_abort(status='scheduled',
-                            event='abort',
-                            response='abort already requested',
-                            need_update=False)
+                             event='abort',
+                             response='abort already requested',
+                             need_update=False)
 
     def test_abort_running_unaborted_job(self):
         self._test_job_abort(status='running',
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     def test_abort_running_abortped_job(self):
         self._test_job_abort(status='running',
-                            event='abort',
-                            response='abort already requested',
-                            need_update=False)
+                             event='abort',
+                             response='abort already requested',
+                             need_update=False)
 
     def test_abort_abortped_unaborted_job(self):
         self._test_job_abort(status='abort',
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     def test_abort_abortped_abortped_job(self):
         self._test_job_abort(status='abort',
-                            event='abort',
-                            response='abort already requested',
-                            need_update=False)
+                             event='abort',
+                             response='abort already requested',
+                             need_update=False)
 
     def test_abort_completed_unaborted_job(self):
         self._test_job_abort(status='completed',
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     def test_abort_completed_abortped_job(self):
         self._test_job_abort(status='completed',
-                            event='abort',
-                            response='abort already requested',
-                            need_update=False)
+                             event='abort',
+                             response='abort already requested',
+                             need_update=False)
 
     def test_abort_emptystatus_unaborted_job(self):
         self._test_job_abort(status='',
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     def test_abort_emptystatus_abortped_job(self):
         self._test_job_abort(status=None,
-                            event='abort',
-                            response='abort already requested',
-                            need_update=False)
+                             event='abort',
+                             response='abort already requested',
+                             need_update=False)
 
     def test_abort_nostatus_unaborted_job(self):
         self._test_job_abort(status=None,
-                            event=None,
-                            response='success',
-                            need_update=True)
+                             event=None,
+                             response='success',
+                             need_update=True)
 
     @patch.object(v1_jobs.Job, 'start')
     def test_execute_start_event(self, mock_start):
         job = v1_jobs.Job({})
-        res = job.execute_event('start', 'my_params')
+        job.execute_event('start', 'my_params')
         mock_start.assert_called_once_with('my_params')
 
     @patch.object(v1_jobs.Job, 'stop')
     def test_execute_stop_event(self, mock_stop):
         job = v1_jobs.Job({})
-        res = job.execute_event('stop', 'my_params')
+        job.execute_event('stop', 'my_params')
         mock_stop.assert_called_once_with('my_params')
 
     @patch.object(v1_jobs.Job, 'abort')
     def test_execute_abort_event(self, mock_abort):
         job = v1_jobs.Job({})
-        res = job.execute_event('abort', 'my_params')
+        job.execute_event('abort', 'my_params')
         mock_abort.assert_called_once_with('my_params')
 
     def test_execute_raises_BadDataFormat_when_event_not_implemented(self):
         job = v1_jobs.Job({})
-        self.assertRaises(BadDataFormat, job.execute_event, 'smile', 'my_params')
+        self.assertRaises(exceptions.BadDataFormat, job.execute_event, 'smile',
+                          'my_params')
 
     def test_expand_action_defaults(self):
         job_doc = {
